@@ -5,7 +5,11 @@
   if (!is.null(ci.lvl) && !is.na(ci.lvl))
     ci <- (1 + ci.lvl) / 2
   else
-    ci <- .975
+    ci <- 0.975
+
+  # degrees of freedom
+  dof <- .get_df(model)
+  tcrit <- stats::qt(ci, df = dof)
 
   # data grid
   newdata <- .data_grid(
@@ -38,7 +42,9 @@
   prdat.sim <- .simulate_zi_predictions(model, newdata, nsim, terms, value_adjustment, condition)
 
   if (is.null(prdat.sim)) {
-    stop("Predicted values could not be computed. Try reducing number of simulation, using argument `nsim` (e.g. `nsim = 100`)", call. = FALSE)
+    insight::format_error(
+      "Predicted values could not be computed. Try reducing number of simulation, using argument `nsim` (e.g. `nsim = 100`)"
+    )
   }
 
   # we need two data grids here: one for all combination of levels from the
@@ -58,8 +64,8 @@
     # to original scale, so we compute proper CI
     if (!is.null(revar)) {
       lf <- insight::link_function(model)
-      prediction_data$conf.low <- exp(lf(prediction_data$conf.low) - stats::qnorm(ci) * sqrt(revar))
-      prediction_data$conf.high <- exp(lf(prediction_data$conf.high) + stats::qnorm(ci) * sqrt(revar))
+      prediction_data$conf.low <- exp(lf(prediction_data$conf.low) - tcrit * sqrt(revar))
+      prediction_data$conf.high <- exp(lf(prediction_data$conf.high) + tcrit * sqrt(revar))
       prediction_data$std.error <- sqrt(prediction_data$std.error^2 + revar)
     }
   }
