@@ -3,9 +3,9 @@
 if (.runThisTest) {
 
   if (suppressWarnings(
-    require("testthat") &&
-    require("rstanarm") &&
-    require("ggeffects")
+    requiet("testthat") &&
+    requiet("rstanarm") &&
+    requiet("ggeffects")
   )) {
     x <- rnorm(30, 0)
     b <- runif(2)
@@ -14,29 +14,30 @@ if (.runThisTest) {
     y <- apply(t(b), 2, `*`, x) + er
     d <- data.frame(y1 = y[,1], y2 = y[,2], x)
     d$group <- sample(c("a", "b", "c"), size = nrow(d), replace = TRUE)
-    m1 <- rstanarm::stan_mvmer(
+    m1 <- suppressWarnings(rstanarm::stan_mvmer(
       list(
         y1 ~ x + (1 | group),
         y2 ~ x + (1 | group)
       ),
       data = d,
       chains = 2,
-      iter = 500
-    )
-    m2 <- rstanarm::stan_glm(y1 ~ x, data = d, chains = 2, iter = 500)
+      iter = 500,
+      refresh = 0
+    ))
+    m2 <- suppressWarnings(rstanarm::stan_glm(y1 ~ x, data = d, chains = 2, iter = 500, refresh = 0))
 
     test_that("ggpredict, rstanarm-ppd", {
-      ggpredict(m1, ppd = TRUE)
-      ggpredict(m1, "x", ppd = TRUE)
-      ggpredict(m2, ppd = TRUE)
-      ggpredict(m2, "x", ppd = TRUE)
+      expect_s3_class(ggpredict(m1, ppd = TRUE), "ggalleffects")
+      expect_s3_class(ggpredict(m1, "x", ppd = TRUE), "data.frame")
+      expect_s3_class(ggpredict(m2, ppd = TRUE), "ggalleffects")
+      expect_s3_class(ggpredict(m2, "x", ppd = TRUE), "data.frame")
     })
 
     test_that("ggpredict, rstanarm-ppd", {
       expect_error(ggpredict(m1, ppd = FALSE))
       expect_error(ggpredict(m1, "x", ppd = FALSE))
-      ggpredict(m2, ppd = FALSE)
-      ggpredict(m2, "x", ppd = FALSE)
+      expect_s3_class(ggpredict(m2, ppd = FALSE), "ggalleffects")
+      expect_s3_class(ggpredict(m2, "x", ppd = FALSE), "data.frame")
     })
   }
 }
